# MaxwellBloch

By [Thomas P Ogden](mailto:t@ogden.eu)

MaxwellBloch is a Python package for solving the coupled Maxwell-Bloch
equations describing the nonlinear propagation of near-resonant light through
thermal atomic vapours.

## License

MIT License. See [License.txt](LICENSE.txt)